#[repr(C)]pub struct InteractionGroups {
pub memberships: Group,
pub filter: Group,
}Expand description
Pairwise filtering using bit masks.
This filtering method is based on two 32-bit values:
- The interaction groups memberships.
- The interaction groups filter.
An interaction is allowed between two filters a and b when two conditions
are met simultaneously:
- The groups membership of
ahas at least one bit set to1in common with the groups filter ofb. - The groups membership of
bhas at least one bit set to1in common with the groups filter ofa.
In other words, interactions are allowed between two filter iff. the following condition is met:
ⓘ
(self.memberships & rhs.filter) != 0 && (rhs.memberships & self.filter) != 0Fields
memberships: GroupGroups memberships.
filter: GroupGroups filter.
Implementations
Sourceimpl InteractionGroups
impl InteractionGroups
Sourcepub const fn new(memberships: Group, filter: Group) -> InteractionGroups
pub const fn new(memberships: Group, filter: Group) -> InteractionGroups
Initializes with the given interaction groups and interaction mask.
Sourcepub const fn all() -> InteractionGroups
pub const fn all() -> InteractionGroups
Allow interaction with everything.
Sourcepub const fn none() -> InteractionGroups
pub const fn none() -> InteractionGroups
Prevent all interactions.
Sourcepub const fn with_memberships(self, memberships: Group) -> InteractionGroups
pub const fn with_memberships(self, memberships: Group) -> InteractionGroups
Sets the group this filter is part of.
Sourcepub const fn with_filter(self, filter: Group) -> InteractionGroups
pub const fn with_filter(self, filter: Group) -> InteractionGroups
Sets the interaction mask of this filter.
Sourcepub const fn test(self, rhs: InteractionGroups) -> bool
pub const fn test(self, rhs: InteractionGroups) -> bool
Check if interactions should be allowed based on the interaction memberships and filter.
An interaction is allowed iff. the memberships of self contain at least one bit set to 1 in common
with the filter of rhs, and vice-versa.